package de.jottyfan.timetrack.spring.done.project.impl;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jooq.DSLContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import de.jottyfan.timetrack.db.done.tables.records.TProjectRecord;
import de.jottyfan.timetrack.spring.done.project.IProjectService;

@Service
@Transactional(transactionManager = "transactionManager")
public class ProjectService implements IProjectService {
	private static final Logger LOGGER = LogManager.getLogger(ProjectService.class);

	@Autowired
	private DSLContext dsl;


	@Override
	public TProjectRecord getProject(Integer id) {
		try {
			return id == null ? new TProjectRecord() : new ProjectGateway(dsl).getProject(id);
		} catch (Exception e) {
			LOGGER.error(e);
			return null;
		}
	}

	@Override
	public Integer doUpsertProject(TProjectRecord bean) {
		try {
			return new ProjectGateway(dsl).upsert(bean);
		} catch (Exception e) {
			LOGGER.error(e);
			return -1;
		}
	}

	@Override
	public Integer doDeleteProject(Integer id) {
		try {
			return new ProjectGateway(dsl).delete(id);
		} catch (Exception e) {
			LOGGER.error(e);
			return -1;
		}
	}
}
